---
title: 'RNAsik: A Pipeline for complete and reproducible RNA-seq analysis that runs anywhere with speed and ease'
tags:
- RNA-seq
- gene expression
- pipeline
- bioinformatics
authors:
- name: Kirill Tsyganov
  orcid: 0000-0002-9195-2626
  affiliation: 1
- name: Andrew James Perry
  orcid: 0000-0001-9256-6068
  affiliation: 1
- name: Stuart Kenneth Archer
  orcid: 0000-0003-0450-1243
  affiliation: 1
- name: David Powell
  orcid: 0000-0002-6639-6250
  affiliation: 1
affiliations:
- name: 'Monash Bioinformatics Platform, Monash University'
  index: 1
date: 6 February 2018
bibliography: paper.bib
---

# Summary

RNA sequencing (RNA-seq) is one of many applications of high throughput sequencing, in which millions of short sequence reads, typically around 100 bases long, are produced from RNA samples with the aim of characterising entire transcriptomes. In order to analyse RNA-seq data, multiple bioinformatics tools are collected together into a pipeline, in which each tool accepts processed data from the previous tool as its input. The RNAsik pipeline streamlines processing of RNA-seq data and facilitates the production of reproducible results. This pipeline can run standalone on workstations, cloud instances, or on High Performance Computing (HPC) clusters. A single RNAsik run gives a comprehensive overview of the experiment and produces output suitable for Differential Gene Expression (DGE) analysis.

With an alignment based approach, RNAsik incorporates two main steps: 1) alignment of short reads from FASTQ files to a reference genome or transcriptome; and 2) counting the number of reads mapped to annotated genomic features (such as genes). The table of counts generated by RNAsik can be further analysed with any contemporary count-based DGE tools/packages - one such package particularly suited to the task is Degust [@Powell2015], a powerful front-end and user friendly tool for DGE data analysis, visualisation and exploration. Additionally RNAsik can produce a number of different quality control (QC) metrics, such as sequencing quality metrics reported using FastQC [@Bioinformatics2011-ve], intra- and inter-genic mapping rates estimation using QualiMap [@Okonechnikov2016-jk], and sequencing library size and GC bias estimation using Picard Tools [@picard-tools2018]. These QC metrics are automatically summarised into a single, dynamic, HTML report generated by MulitQC [@Ewels2016-ik].

Other features of the RNAsik pipeline include the ability to mark duplicated reads using Picard Tools [@picard-tools2018], sorting and indexing of alignments using Samtools [@Li2009-aa] to enable viewing in genome browser applications such as IGV [Robinson2011-du], an enhanced table of counts with additional meta-information about each gene (e.g. biotype and human readable gene names), and ready-to-use coverage plots for every sample using bedtools2 [@Quinlan2010-am] and UCSC tools [@Raney2014-ti]. The RNAsik pipeline logs every step of processing including the number of samples and associated FASTQ files, software tool versions and sequencing strand information. 

RNAsik is written in BigDataScript (BDS) [@Cingolani2015-nm], which is a domain-specific language (DSL). BDS generates an additional HTML report alongside a typical RNAsik analysis. In addition to RNAsik internal logging, this report holds system information such as run-time information and the exit status for every tool. RNAsik employs many other useful features within BDS such as inbuilt checkpointing for retries on failure and ability to talk to an HPC cluster queue directly. 

RNAsik incorporates commonly used tools such as STAR aligner [@Dobin2013-yw], featureCounts [@Liao2014-qo] and samtools [@Li2009-aa]. However, one can extend RNAsik with other new tools and features. Recently, RNAsik has been extended to include two other aligners, Hisat2 [@Kim2015-ju] and BWA-MEM [@Li2013-bz]. This broadens the scope of RNAsik to bacterial RNA-seq analysis and improves diversity.
RNAsik is an open-source project under Apache License 2.0, and contributions are welcome. In the near future, there are plans to extend RNAsik in several directions including the incorporation of alignment-free read quantification and an RNA-seq variant calling option [@Sun2016-ud]. RNAsik simplifies and speeds up RNA-seq analysis and automates many of the QC steps that are important but often overlooked.

# References
